@@ -10,7 +10,9 @@ except DistributionNotFound:
     # package is not installed
     pass
 
+from .ansi import style
+from .argparse_custom import Cmd2ArgumentParser, CompletionItem
 from .cmd2 import Cmd, Statement, EmptyStatement, categorize
 from .cmd2 import with_argument_list, with_argparser, with_argparser_and_unknown_args, with_category
 from .constants import DEFAULT_SHORTCUTS
-from .pyscript_bridge import CommandResult
+from .py_bridge import CommandResult
