@@ -18,17 +18,15 @@ from . import constants
 def is_quoted(arg: str) -> bool:
     """
     Checks if a string is quoted
+
     :param arg: the string being checked for quotes
     :return: True if a string is quoted
     """
     return len(arg) > 1 and arg[0] == arg[-1] and arg[0] in constants.QUOTES
 
 
-def quote_string_if_needed(arg: str) -> str:
-    """ Quotes a string if it contains spaces and isn't already quoted """
-    if is_quoted(arg) or ' ' not in arg:
-        return arg
-
+def quote_string(arg: str) -> str:
+    """Quote a string"""
     if '"' in arg:
         quote = "'"
     else:
@@ -37,8 +35,16 @@ def quote_string_if_needed(arg: str) -> str:
     return quote + arg + quote
 
 
+def quote_string_if_needed(arg: str) -> str:
+    """Quote a string if it contains spaces and isn't already quoted"""
+    if is_quoted(arg) or ' ' not in arg:
+        return arg
+
+    return quote_string(arg)
+
+
 def strip_quotes(arg: str) -> str:
-    """ Strip outer quotes from a string.
+    """Strip outer quotes from a string.
 
      Applies to both single and double quotes.
 
@@ -483,7 +489,7 @@ class ByteBuf(object):
 
 class ProcReader(object):
     """
-    Used to captured stdout and stderr from a Popen process if any of those were set to subprocess.PIPE.
+    Used to capture stdout and stderr from a Popen process if any of those were set to subprocess.PIPE.
     If neither are pipes, then the process will run normally and no output will be captured.
     """
     def __init__(self, proc: subprocess.Popen, stdout: Union[StdSim, TextIO],
@@ -615,3 +621,19 @@ class RedirectionSavedState(object):
 
         # If the command created a process to pipe to, then then is its reader
         self.pipe_proc_reader = None
+
+
+# noinspection PyUnusedLocal
+def basic_complete(text: str, line: str, begidx: int, endidx: int, match_against: Iterable) -> List[str]:
+    """
+    Basic tab completion function that matches against a list of strings without considering line contents
+    or cursor position. The args required by this function are defined in the header of Pythons's cmd.py.
+
+    :param text: the string prefix we are attempting to match (all matches must begin with it)
+    :param line: the current input line with leading whitespace removed
+    :param begidx: the beginning index of the prefix text
+    :param endidx: the ending index of the prefix text
+    :param match_against: the strings being matched against
+    :return: a list of possible tab completions
+    """
+    return [cur_match for cur_match in match_against if cur_match.startswith(text)]
